==> confixx_3.3.1.orig.tar.gz: confixx-3.3.1.orig/admin/html/poplogin/index.php <==
<?php
########## Confixx(R) 3.2 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

include_once( 'auth.php' );

if( ! isset( $server_id ) ){
	$server_id = $ServerID;
 }

if( $confixx_interface_version == 'classic20' ){
  if (strpos($HTTP_USER_AGENT,"IE") > 0 ){
    $strRows = "77,28,*,41";
  }else{
    $strRows = "77,34,*,41";
  }
  
  if( $master_confixx == 2 && ! $wrap ){

		$lcPath = "poplogin/$PHP_AUTH_USER/";

		$lrId    = safe_query( "SELECT confixx_domain FROM admin WHERE server_id='$server_id'" );
		$lcDomain  = db_fetch_array( $lrId, 'N' );
		db_free_query( $lrId );

 		$lcPath  = "http://$lcDomain/$lcPath".'?wrap=1&SID='.urlencode(session_id());
 		
	  ?>
	  <html>
    <head>
    <title>Confixx Professional</title>
    </head>
    <frameset  rows ="*" border=0 frameborder=0 framespacing=0>
      <frame name="wrapFrame" src="<?=$lcPath?>" marginheight=0 marginwidth=0 scrolling=no  noresize frameborder=0>
    </frameset>     
    </html>
  	<?
	}else{
	              
  ?>
  <html>
  <head>
  <title>Confixx Professional</title>
  </head>
  <frameset  rows ="<?=$strRows?>" border=0 frameborder=0 framespacing=0>
    <frame name=fraTitle            src="title.php" marginheight=0 marginwidth=0 scrolling=no   noresize frameborder=0>
    <frame name=fraToolbar          src="toolbar.php" marginheight=0 marginwidth=0 scrolling=no   noresize frameborder=0>
    <frameset cols ="10,*,10" border=1 frameborder=0 framespacing=0>
      <frame name=fraLeft             src="left.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
      <frame name=fraContent  src="index2.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
      <frame name=fraRight    src="right.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
    </frameset>
    <frame name=fraHelp src="bottom.php" marginheight=0 marginwidth=0 scrolling=no       noresize frameborder=0>
  </frameset>     
  </html>
  <?
	}
}else{
	$default_content = $gui->make_menu_item( 'emaillist',
	               	                         ltext( 'm_postfach' ),
		                                       $gui->make_menu_target_int( 'email_postfach.php' )
	                                       );

	$index_php = $gui->make_main_frameset( $default_content );
	
	if( ! isset( $wrap ) ){
	  $wrap = 0;
	}
	
	if( $master_confixx == 2 && ! $wrap ){
	  $index_php->drawWrapper();
	}else{
	  $index_php->draw();
	}	
}
?>

==> confixx_3.3.3.orig.tar.gz: confixx-3.3.3.orig/admin/html/poplogin/index.php <==
<?php
########## Confixx(R) 3.2 Professional ############
####### Copyright SWsoft, Inc. 2004-2006 ##########
##### http://www.swsoft.com - info@swsoft.com #####

include_once( 'auth.php' );

if( ! isset( $server_id ) ){
	$server_id = $ServerID;
 }

if( $confixx_interface_version == 'classic20' ){
  if (strpos($HTTP_USER_AGENT,"IE") > 0 ){
    $strRows = "77,28,*,41";
  }else{
    $strRows = "77,34,*,41";
  }
  
  if( $master_confixx == 2 && ! $wrap ){

		$lcPath = "poplogin/$PHP_AUTH_USER/";

		$lrId    = safe_query( "SELECT confixx_domain FROM admin WHERE server_id='$server_id'" );
		$lcDomain  = db_fetch_array( $lrId, 'N' );
		db_free_query( $lrId );

 		$lcPath  = "http://$lcDomain/$lcPath".'?wrap=1&SID='.urlencode(session_id());
 		
	  ?>
	  <html>
    <head>
    <title>Parallels Confixx</title>
    </head>
    <frameset  rows ="*" border=0 frameborder=0 framespacing=0>
      <frame name="wrapFrame" src="<?=$lcPath?>" marginheight=0 marginwidth=0 scrolling=no  noresize frameborder=0>
    </frameset>     
    </html>
  	<?
	}else{
	              
  ?>
  <html>
  <head>
  <title>Parallels Confixx</title>
  </head>
  <frameset  rows ="<?=$strRows?>" border=0 frameborder=0 framespacing=0>
    <frame name=fraTitle            src="title.php" marginheight=0 marginwidth=0 scrolling=no   noresize frameborder=0>
    <frame name=fraToolbar          src="toolbar.php" marginheight=0 marginwidth=0 scrolling=no   noresize frameborder=0>
    <frameset cols ="10,*,10" border=1 frameborder=0 framespacing=0>
      <frame name=fraLeft             src="left.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
      <frame name=fraContent  src="index2.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
      <frame name=fraRight    src="right.php" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
    </frameset>
    <frame name=fraHelp src="bottom.php" marginheight=0 marginwidth=0 scrolling=no       noresize frameborder=0>
  </frameset>     
  </html>
  <?
	}
}else{
	$default_content = $gui->make_menu_item( 'emaillist',
	               	                         ltext( 'm_postfach' ),
		                                       $gui->make_menu_target_int( 'email_postfach.php' )
	                                       );

	$index_php = $gui->make_main_frameset( $default_content );
	
	if( ! isset( $wrap ) ){
	  $wrap = 0;
	}
	
	if( $master_confixx == 2 && ! $wrap ){
	  $index_php->drawWrapper();
	}else{
	  $index_php->draw();
	}	
}
?>
